@@ -7,40 +7,40 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
-use base 'Class::MOP::Method';
+use base 'Class::MOP::Method::Generated';
 
 sub new {
     my $class   = shift;
     my %options = @_;
-    
+
     (exists $options{attribute})
         || confess "You must supply an attribute to construct with";
-        
+
     (exists $options{accessor_type})
-        || confess "You must supply an accessor_type to construct with"; 
-        
+        || confess "You must supply an accessor_type to construct with";
+
     (blessed($options{attribute}) && $options{attribute}->isa('Class::MOP::Attribute'))
-        || confess "You must supply an attribute which is a 'Class::MOP::Attribute' instance";    
-        
+        || confess "You must supply an attribute which is a 'Class::MOP::Attribute' instance";
+
     my $self = bless {
         # from our superclass
         '&!body'          => undef,
         # specific to this subclass
         '$!attribute'     => $options{attribute},
         '$!is_inline'     => ($options{is_inline} || 0),
-        '$!accessor_type' => $options{accessor_type},        
+        '$!accessor_type' => $options{accessor_type},
     } => $class;
-    
-    # we don't want this creating 
-    # a cycle in the code, if not 
+
+    # we don't want this creating
+    # a cycle in the code, if not
     # needed
     weaken($self->{'$!attribute'});
-    
-    $self->intialize_body;
-    
+
+    $self->initialize_body;
+
     return $self;
 }
 
@@ -48,20 +48,19 @@ sub new {
 
 sub associated_attribute { (shift)->{'$!attribute'}     }
 sub accessor_type        { (shift)->{'$!accessor_type'} }
-sub is_inline            { (shift)->{'$!is_inline'}     }
 
-## factory 
+## factory
 
-sub intialize_body {
+sub initialize_body {
     my $self = shift;
-    
+
     my $method_name = join "_" => (
-        'generate', 
-        $self->accessor_type, 
+        'generate',
+        $self->accessor_type,
         'method',
         ($self->is_inline ? 'inline' : ())
     );
-    
+
     eval { $self->{'&!body'} = $self->$method_name() };
     die $@ if $@;
 }
@@ -69,7 +68,7 @@ sub intialize_body {
 ## generators
 
 sub generate_accessor_method {
-    my $attr = (shift)->associated_attribute; 
+    my $attr = (shift)->associated_attribute;
     return sub {
         $attr->set_value($_[0], $_[1]) if scalar(@_) == 2;
         $attr->get_value($_[0]);
@@ -77,30 +76,30 @@ sub generate_accessor_method {
 }
 
 sub generate_reader_method {
-    my $attr = (shift)->associated_attribute; 
-    return sub { 
+    my $attr = (shift)->associated_attribute;
+    return sub {
         confess "Cannot assign a value to a read-only accessor" if @_ > 1;
         $attr->get_value($_[0]);
-    };   
+    };
 }
 
 sub generate_writer_method {
-    my $attr = (shift)->associated_attribute; 
+    my $attr = (shift)->associated_attribute;
     return sub {
         $attr->set_value($_[0], $_[1]);
     };
 }
 
 sub generate_predicate_method {
-    my $attr = (shift)->associated_attribute; 
-    return sub { 
+    my $attr = (shift)->associated_attribute;
+    return sub {
         $attr->has_value($_[0])
     };
 }
 
 sub generate_clearer_method {
-    my $attr = (shift)->associated_attribute; 
-    return sub { 
+    my $attr = (shift)->associated_attribute;
+    return sub {
         $attr->clear_value($_[0])
     };
 }
@@ -109,7 +108,7 @@ sub generate_clearer_method {
 
 
 sub generate_accessor_method_inline {
-    my $attr          = (shift)->associated_attribute; 
+    my $attr          = (shift)->associated_attribute;
     my $attr_name     = $attr->name;
     my $meta_instance = $attr->associated_class->instance_metaclass;
 
@@ -123,7 +122,7 @@ sub generate_accessor_method_inline {
 }
 
 sub generate_reader_method_inline {
-    my $attr          = (shift)->associated_attribute; 
+    my $attr          = (shift)->associated_attribute;
     my $attr_name     = $attr->name;
     my $meta_instance = $attr->associated_class->instance_metaclass;
 
@@ -137,7 +136,7 @@ sub generate_reader_method_inline {
 }
 
 sub generate_writer_method_inline {
-    my $attr          = (shift)->associated_attribute; 
+    my $attr          = (shift)->associated_attribute;
     my $attr_name     = $attr->name;
     my $meta_instance = $attr->associated_class->instance_metaclass;
 
@@ -151,12 +150,12 @@ sub generate_writer_method_inline {
 
 
 sub generate_predicate_method_inline {
-    my $attr          = (shift)->associated_attribute; 
+    my $attr          = (shift)->associated_attribute;
     my $attr_name     = $attr->name;
     my $meta_instance = $attr->associated_class->instance_metaclass;
 
-    my $code = eval 'sub {'
-        . 'defined ' . $meta_instance->inline_get_slot_value('$_[0]', "'$attr_name'") . ' ? 1 : 0'
+    my $code = eval 'sub {' .
+       $meta_instance->inline_is_slot_initialized('$_[0]', "'$attr_name'")
     . '}';
     confess "Could not generate inline predicate because : $@" if $@;
 
@@ -164,7 +163,7 @@ sub generate_predicate_method_inline {
 }
 
 sub generate_clearer_method_inline {
-    my $attr          = (shift)->associated_attribute; 
+    my $attr          = (shift)->associated_attribute;
     my $attr_name     = $attr->name;
     my $meta_instance = $attr->associated_class->instance_metaclass;
 
@@ -182,7 +181,7 @@ __END__
 
 =pod
 
-=head1 NAME 
+=head1 NAME
 
 Class::MOP::Method::Accessor - Method Meta Object for accessors
 
@@ -195,14 +194,14 @@ Class::MOP::Method::Accessor - Method Meta Object for accessors
         is_inline     => 1,
         accessor_type => 'reader',
     );
-    
+
     $reader->body->($instance); # call the reader method
 
 =head1 DESCRIPTION
 
-This is a C<Class::MOP::Method> subclass which is used interally 
-by C<Class::MOP::Attribute> to generate accessor code. It can 
-handle generation of readers, writers, predicate and clearer 
+This is a C<Class::MOP::Method> subclass which is used interally
+by C<Class::MOP::Attribute> to generate accessor code. It can
+handle generation of readers, writers, predicate and clearer
 methods, both as closures and as more optimized inline methods.
 
 =head1 METHODS
@@ -211,20 +210,20 @@ methods, both as closures and as more optimized inline methods.
 
 =item B<new (%options)>
 
-This creates the method based on the criteria in C<%options>, 
+This creates the method based on the criteria in C<%options>,
 these options are:
 
 =over 4
 
 =item I<attribute>
 
-This must be an instance of C<Class::MOP::Attribute> which this 
+This must be an instance of C<Class::MOP::Attribute> which this
 accessor is being generated for. This paramter is B<required>.
 
 =item I<accessor_type>
 
-This is a string from the following set; reader, writer, accessor, 
-predicate or clearer. This is used to determine which type of 
+This is a string from the following set; reader, writer, accessor,
+predicate or clearer. This is used to determine which type of
 method is to be generated.
 
 =item I<is_inline>
@@ -246,17 +245,17 @@ This returns the boolean which was passed into C<new>.
 
 This returns the attribute instance which was passed into C<new>.
 
-=item B<intialize_body>
+=item B<initialize_body>
 
-This will actually generate the method based on the specified 
+This will actually generate the method based on the specified
 criteria passed to the constructor.
 
 =back
 
 =head2 Method Generators
 
-These methods will generate appropriate code references for 
-the various types of accessors which are supported by 
+These methods will generate appropriate code references for
+the various types of accessors which are supported by
 C<Class::MOP::Attribute>. The names pretty much explain it all.
 
 =over 4
@@ -289,12 +288,12 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006, 2007 by Infinity Interactive, Inc.
+Copyright 2006-2008 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
 
