@@ -226,18 +226,25 @@ __END__
 
 Class::MOP::Package - Package Meta Object
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
+This is an abstraction of a Perl 5 package, it is a superclass of
+L<Class::MOP::Class> and provides all of the symbol table 
+introspection methods.
+
 =head1 METHODS
 
 =over 4
 
 =item B<meta>
 
+Returns a metaclass for this package.
+
 =item B<initialize ($package_name)>
 
+This will initialize a Class::MOP::Package instance which represents 
+the package of C<$package_name>.
+
 =item B<name>
 
 This is a read-only attribute which returns the package name for the 
